@@ -393,7 +393,12 @@ sub run_plugin {
     for my $rp (@runtime_params){
       $rp=~/(\S+?)=(.*)/;
       #warn $1; warn $2;
-      $cmd.= " --param $1='$2'";
+      my $k = $1; my $v = $2;
+  	  if ($^O  =~ 'MSWin') {
+        $cmd.= " --param $k=$v";
+      } else {
+        $cmd.= " --param $k='$v'";
+      }
     }
 
 
